@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <string.h>
 
 #ifdef HAVE_CONFIG_H
@@ -83,6 +84,10 @@
 #define gbl_buffer_size 512
 extern char gbl_buffer[gbl_buffer_size];
 
+typedef enum {
+	false = 0,
+	true  = 1
+} cherokee_boolean_t;
 
 typedef enum {
 	ret_nomem          = -3, 
