@@ -246,12 +246,15 @@ add_error_code_string_to_buffer (cherokee_connection_t *cnt)
 static ret_t
 send_buffer_unsafe (cherokee_connection_t *cnt)
 {
-	int ret;
+	ret_t ret;
+	int   sent;
+
+//	ret = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
+	ret = cherokee_socket_write (cnt->socket, cnt->buffer, &sent);
 
-	ret = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
 	cherokee_buffer_make_empty (cnt->buffer);
 
-	if (ret <= 0) {
+	if (ret <= ret_ok) {
 		cnt->keep_alive = 0;
 		return ret_error;
 	}
@@ -274,7 +277,7 @@ process_handler_complex_headers (cherokee_connection_t *cnt)
 	
 	cherokee_header_new (&header);
 	
-	ret = cherokee_header_parse (header, cnt->header_buffer, 0);
+	ret = cherokee_header_parse (header, cnt->header_buffer, header_type_basic);
 	if (ret < ret_ok) {
 		return ret;
 	}
@@ -312,35 +315,6 @@ exit:
 	return ret;
 }
 
-ret_t 
-cherokee_connection_build_header (cherokee_connection_t *cnt)
-{
-	ret_t ret;
-
-	if (http_type_200(cnt->error_code)) {
-		/* Sanity checks
-		 */
-		if (cnt->handler == NULL) return ret_error;
-
-		/* Try to get the headers from the handler
-		 */
-		ret = cherokee_handler_add_headers (cnt->handler, cnt->header_buffer);
-		if (ret == ret_eagain) return ret;
-
-		/* Does it need to be processed?
-		 */
-		if (HANDLER_SUPPORT_COMPLEX_HEADERS(cnt->handler)) {
-			process_handler_complex_headers (cnt);
-		}
-	}
-
-	/* Add the server headers	
-	 */
-	build_response_header (cnt);
-
-	return ret_ok;
-}
-
 
 static void
 build_response_header (cherokee_connection_t *cnt)
@@ -451,6 +425,37 @@ build_response_header (cherokee_connection_t *cnt)
 	cherokee_buffer_add (cnt->buffer, CRLF, 2);
 }
 
+
+ret_t 
+cherokee_connection_build_header (cherokee_connection_t *cnt)
+{
+	ret_t ret;
+
+	if (http_type_200(cnt->error_code)) {
+		/* Sanity checks
+		 */
+		if (cnt->handler == NULL) return ret_error;
+
+		/* Try to get the headers from the handler
+		 */
+		ret = cherokee_handler_add_headers (cnt->handler, cnt->header_buffer);
+		if (ret == ret_eagain) return ret;
+
+		/* Does it need to be processed?
+		 */
+		if (HANDLER_SUPPORT_COMPLEX_HEADERS(cnt->handler)) {
+			process_handler_complex_headers (cnt);
+		}
+	}
+
+	/* Add the server headers	
+	 */
+	build_response_header (cnt);
+
+	return ret_ok;
+}
+
+
 ret_t
 cherokee_connection_send_header (cherokee_connection_t *cnt)
 {
@@ -538,34 +543,25 @@ cherokee_connection_send_header_and_mmaped (cherokee_connection_t *cnt)
 ret_t
 cherokee_connection_recv (cherokee_connection_t *cnt, cherokee_buffer_t *buffer)
 {
-	int  readed;
-	char tmp[DEFAULT_RECV_SIZE];
+	ret_t   ret;
+	ssize_t readed;
 	
-	readed = read (SOCKET_FD(cnt->socket), tmp, DEFAULT_RECV_SIZE);
-
-	if (readed > 0) {
-		cherokee_buffer_add (buffer, tmp, readed);
-
+//	ret = cherokee_buffer_read_from_fd (buffer, SOCKET_FD(cnt->socket), DEFAULT_RECV_SIZE, &readed);
+	ret = cherokee_socket_read (cnt->socket, buffer, DEFAULT_RECV_SIZE, &readed);
+	switch (ret) {
+	case ret_ok:
 		/* Add to the virtual host data sent counter
 		 */
 		CONN_VSRV(cnt)->data.rx += readed;
-
 		return ret_ok;
-	} 
-	else if (readed == 0) {
-		/* Remote machine cancel the download
-		 */
-		return ret_eof;
-	}
 
-	switch (errno) {
-	case EAGAIN:
+	case ret_eagain:
 		return ret_eagain;
-	case ECONNRESET:
+
+	case ret_eof:
 		return ret_eof;
 	}
 
-	printf ("Unknown error: read(%2d, ..) -> errno=%d '%s'\n", SOCKET_FD(cnt->socket), errno, strerror(errno));
 	return ret_error;
 }
 
@@ -639,9 +635,11 @@ cherokee_connection_set_cork (cherokee_connection_t *cnt, int enable)
 ret_t
 cherokee_connection_send (cherokee_connection_t *cnt)
 {
-	int sent;
+	ret_t ret;
+	int   sent;
 
-	sent = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
+	// sent = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
+	ret = cherokee_socket_write (cnt->socket, cnt->buffer, &sent);
 
 	if (sent > 0) {
 		if (sent == cnt->buffer->len) {
@@ -1015,7 +1013,7 @@ cherokee_connection_get_request (cherokee_connection_t *cnt)
 
 	/* Header parsing
 	 */
-	ret = cherokee_header_parse (cnt->header, cnt->buffer, 1);
+	ret = cherokee_header_parse (cnt->header, cnt->buffer, header_type_request);
 	if (ret < ret_ok) goto error;
 
 	/* Maybe read the POST data
