@@ -493,6 +493,11 @@ fdpoll_poll_reset (cherokee_fdpoll_t *fdp, int fd)
 /***********************************************************************/
 #ifdef USE_SELECT
 
+#ifndef INFTIM
+# define INFTIM -1
+#endif
+
+
 ret_t 
 fdpoll_select_new (cherokee_fdpoll_t **fdp)
 {
@@ -506,6 +511,7 @@ fdpoll_select_new (cherokee_fdpoll_t **fdp)
 	n->select_fds    = (int*) malloc(sizeof(int) * n->nfiles);
 	n->select_fdidx  = (int*) malloc(sizeof(int) * n->nfiles);
 	n->select_rfdidx = (int*) malloc(sizeof(int) * n->nfiles);
+	n->fd_rw         = (int*) malloc(sizeof(int) * n->nfiles);
 
 	n->nselect_fds   = 0;
 	n->maxfd         = -1;
@@ -514,6 +520,7 @@ fdpoll_select_new (cherokee_fdpoll_t **fdp)
 	for (i = 0; i < n->nfiles; ++i) {
 		n->select_fds[i]   = -1;
 		n->select_fdidx[i] = -1;
+		n->fd_rw[i]        = -1;
 	}
 
 	*fdp = n;
@@ -526,14 +533,22 @@ fdpoll_select_free (cherokee_fdpoll_t *fdp)
 {
 	if (fdp->select_fds != NULL) {
 		free (fdp->select_fds);
+		fdp->select_fds = NULL;
 	}
 	
 	if (fdp->select_fdidx != NULL) {
 		free (fdp->select_fdidx);
+		fdp->select_fdidx = NULL;
 	}
 	
 	if (fdp->select_rfdidx != NULL) {
 		free (fdp->select_rfdidx);
+		fdp->select_rfdidx = NULL;
+	}
+
+	if (fdp->fd_rw != NULL) {
+		free (fdp->fd_rw);
+		fdp->fd_rw = NULL;
 	}
 
 	free (fdp);
@@ -577,6 +592,7 @@ fdpoll_select_add (cherokee_fdpoll_t *fdp, int fd, int rw)
 	}
 
 	fdp->select_fdidx[fd] = fdp->nselect_fds;
+	fdp->fd_rw[fd]        = rw;
 	fdp->nselect_fds++;
 
 	return ret_ok;
@@ -597,7 +613,8 @@ fdpoll_select_del (cherokee_fdpoll_t *fdp, int fd)
 	fdp->select_fds[idx]                  = fdp->select_fds[fdp->nselect_fds];
 	fdp->select_fdidx[fdp->select_fds[idx]] = idx;
 	fdp->select_fds[fdp->nselect_fds]       = -1;
-	fdp->select_fdidx[fd]                 = -1;
+	fdp->select_fdidx[fd]                   = -1;
+	fdp->fd_rw[fd]                          = -1;
 
 	FD_CLR (fd, &fdp->master_rfdset);
 	FD_CLR (fd, &fdp->master_wfdset);
@@ -661,7 +678,7 @@ select_get_maxfd (cherokee_fdpoll_t *fdp)
 		fdp->maxfd_changed = 0;
         }
 
-	return maxfd;
+	return fdp->maxfd;
 }
 
 
@@ -688,8 +705,8 @@ fdpoll_select_watch (cherokee_fdpoll_t *fdp, int timeout_msecs)
 	}
 
 	ridx = 0;
-	for (idx = 0; idx < nselect_fds; ++idx) {
-		if (select_check_fd( select_fds[idx])) {
+	for (idx = 0; idx < fdp->nselect_fds; ++idx) {
+		if (fdpoll_select_check (fdp, fdp->select_fds[idx], 0)) {
 			fdp->select_rfdidx[ridx++] = fdp->select_fds[idx];
 			if (ridx == r) break;
 		}
@@ -698,6 +715,12 @@ fdpoll_select_watch (cherokee_fdpoll_t *fdp, int timeout_msecs)
 	return ridx;        /* should be equal to r */
 }
 
+
+ret_t 
+fdpoll_select_reset (cherokee_fdpoll_t *fdp, int fd)
+{
+}
+
 #endif /* USE_SELECT */
 
 
