@@ -90,13 +90,8 @@ typedef struct {
 #endif
 	
 #ifdef USE_SELECT
-/*
-	long   nwatches;
-	int   *fd_rw;
-	void **fd_data;
-	int    nreturned;
-	int    next_ridx;
-*/
+	int    *fd_rw;
+
 	fd_set  master_rfdset;
 	fd_set  master_wfdset;
 	fd_set  working_rfdset;
