@@ -166,7 +166,7 @@ cherokee_handler_dirlist_init (cherokee_handler_dirlist_t *n)
 
 	/* Build de local request
 	 */
-	cherokee_buffer_add (conn->local_directory, conn->request->buf, conn->request->len);
+	cherokee_buffer_add_buffer (conn->local_directory, conn->request);
 	n->dir = opendir (conn->local_directory->buf);
 	cherokee_buffer_drop_endding (conn->local_directory, conn->request->len);
 
@@ -244,7 +244,7 @@ cherokee_handler_dirlist_step (cherokee_handler_dirlist_t *dhdl, cherokee_buffer
 		}
 
 		cherokee_buffer_add (buffer, "><h1>Index of ", 14);
-		cherokee_buffer_add (buffer, conn->request->buf, conn->request->len);
+		cherokee_buffer_add_buffer (buffer, conn->request);
 		cherokee_buffer_add (buffer, "</h1><hr><pre>", 14);
 		
 		if (dhdl->header != NULL) {
