@@ -372,10 +372,14 @@ cherokee_handler_file_add_headers (cherokee_handler_file_t *fhdl,
 		HANDLER_CONN(fhdl)->keep_alive = 0;
 	}
 
-	/* Add "Content-Type:" header
+	/* Add MIME related headers: 
+	 * "Content-Type:" and "Cache-Control: max-age="
 	 */
 	if (fhdl->mime != NULL) {
-		cherokee_buffer_add_va (buffer, "Content-Type: %s"CRLF, MIME_ENTRY_NAME(fhdl->mime));
+		cherokee_buffer_add (buffer, "Content-Type: ", 14);
+		cherokee_buffer_add_buffer (buffer, MIME_ENTRY_NAME(fhdl->mime));
+		cherokee_buffer_add (buffer, CRLF, 2);
+
 		if (MIME_ENTRY_AGE(fhdl->mime) != -1) {
 			cherokee_buffer_add_va (buffer, "Cache-Control: max-age=%d"CRLF, 
 						MIME_ENTRY_AGE(fhdl->mime));
