@@ -48,20 +48,27 @@ typedef struct {
 } cherokee_header_unknown_entry_t;
 
 typedef enum {
-	   header_connection,
-	   header_range,
-	   header_keepalive,
-	   header_accept,
-	   header_host,
-	   header_accept_encoding,
-	   header_user_agent,
-	   header_keep_alive,
-	   header_referer,
-	   header_location,
-	   header_content_length,
-	   HEADER_LENGTH
+	header_connection,
+	header_range,
+	header_keepalive,
+	header_accept,
+	header_host,
+	header_accept_encoding,
+	header_user_agent,
+	header_keep_alive,
+	header_referer,
+	header_location,
+	header_content_length,
+	HEADER_LENGTH
 } cherokee_common_header_t;
 
+typedef enum {
+	header_type_request,
+	header_type_response, 
+	header_type_basic
+} cherokee_type_header_t;
+
+
 typedef struct {
 	/* Known headers
 	 */
@@ -76,6 +83,7 @@ typedef struct {
 	 */
 	cherokee_http_version_t version;
 	cherokee_http_method_t  method;
+	cherokee_http_t         response;
 
 	/* Request
 	 */
@@ -95,14 +103,16 @@ typedef struct {
 } cherokee_header_t;
 
 
-#define HDR(h)        ((cherokee_header_t *)(h))
-#define HDR_METHOD(h) ((cherokee_header_t *)(h))->method
+#define HDR(h)          ((cherokee_header_t *)(h))
+#define HDR_METHOD(h)   (HDR(h)->method)
+#define HDR_RESPONSE(h) (HDR(h)->response)
+
 
 ret_t cherokee_header_new   (cherokee_header_t **hdr);
 ret_t cherokee_header_free  (cherokee_header_t  *hdr);
 ret_t cherokee_header_clean (cherokee_header_t  *hdr);
 
-ret_t cherokee_header_parse         (cherokee_header_t  *hdr, cherokee_buffer_t *buffer, int http_request);
+ret_t cherokee_header_parse         (cherokee_header_t  *hdr, cherokee_buffer_t *buffer, cherokee_type_header_t type);
 ret_t cherokee_header_copy_request  (cherokee_header_t  *hdr, cherokee_buffer_t *request);
 
 ret_t cherokee_header_get_arguments (cherokee_header_t  *hdr, cherokee_buffer_t *qstring, cherokee_table_t *arguments);
