@@ -143,7 +143,7 @@ cherokee_mime_entry_new  (cherokee_mime_entry_t **mentry)
 
 	INIT_LIST_HEAD(&n->base);
 	n->max_age   = -1;
-	n->mime_name = NULL;
+	cherokee_buffer_new (&n->mime_name);
 
 	*mentry = n;
 	return ret_ok;
@@ -154,7 +154,7 @@ ret_t
 cherokee_mime_entry_free (cherokee_mime_entry_t *mentry)
 {
 	if (mentry->mime_name != NULL) {
-		free (mentry->mime_name);
+		cherokee_buffer_free (mentry->mime_name);
 		mentry->mime_name = NULL;
 	}
 
