@@ -585,12 +585,12 @@ static const unsigned short yyrline[] =
      233,   236,   237,   238,   239,   240,   241,   242,   245,   246,
      249,   250,   253,   254,   257,   258,   262,   271,   283,   292,
      305,   310,   315,   330,   329,   355,   356,   358,   359,   362,
-     375,   380,   385,   393,   398,   406,   411,   416,   433,   450,
-     468,   481,   480,   511,   532,   553,   570,   575,   582,   587,
-     602,   607,   622,   627,   633,   640,   645,   650,   653,   656,
-     659,   662,   665,   669,   698,   699,   705,   704,   729,   728,
-     806,   812,   823,   828,   850,   859,   880,   881,   884,   885,
-     888,   893,   924,   936,   948
+     375,   380,   385,   390,   395,   403,   408,   413,   430,   447,
+     465,   478,   477,   508,   529,   550,   567,   572,   579,   584,
+     599,   604,   619,   624,   630,   637,   642,   647,   650,   653,
+     656,   659,   662,   666,   695,   696,   702,   701,   726,   725,
+     803,   809,   820,   825,   847,   856,   877,   878,   881,   882,
+     885,   890,   921,   933,   945
 };
 #endif
 
@@ -1554,22 +1554,19 @@ yyreduce:
   case 62:
 #line 386 "read_config_grammar.y"
     {
-	   cherokee_mime_t *mime;
-
-	   cherokee_mime_init_with_file (&mime, (char *)yyvsp[0].string);
-	   free (yyvsp[0].string);
+	   SRV(server)->mime_file = yyvsp[0].string;
 }
     break;
 
   case 63:
-#line 394 "read_config_grammar.y"
+#line 391 "read_config_grammar.y"
     {
 	   SRV(server)->icons_file = yyvsp[0].string;
 }
     break;
 
   case 64:
-#line 399 "read_config_grammar.y"
+#line 396 "read_config_grammar.y"
     {
 	   SRV(server)->timeout = yyvsp[0].number;
 
@@ -1579,21 +1576,21 @@ yyreduce:
     break;
 
   case 65:
-#line 407 "read_config_grammar.y"
+#line 404 "read_config_grammar.y"
     {
 	   SRV(server)->keepalive = yyvsp[0].number;
 }
     break;
 
   case 66:
-#line 412 "read_config_grammar.y"
+#line 409 "read_config_grammar.y"
     {
 	   SRV(server)->keepalive_max = yyvsp[0].number;
 }
     break;
 
   case 67:
-#line 417 "read_config_grammar.y"
+#line 414 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1612,7 +1609,7 @@ yyreduce:
     break;
 
   case 68:
-#line 434 "read_config_grammar.y"
+#line 431 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1631,7 +1628,7 @@ yyreduce:
     break;
 
   case 69:
-#line 451 "read_config_grammar.y"
+#line 448 "read_config_grammar.y"
     {
 #ifdef HAVE_TLS
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
@@ -1650,7 +1647,7 @@ yyreduce:
     break;
 
   case 70:
-#line 469 "read_config_grammar.y"
+#line 466 "read_config_grammar.y"
     {
 	   ret_t ret;
 
@@ -1664,7 +1661,7 @@ yyreduce:
     break;
 
   case 71:
-#line 481 "read_config_grammar.y"
+#line 478 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   cherokee_module_info_t *info;
@@ -1693,14 +1690,14 @@ yyreduce:
     break;
 
   case 72:
-#line 507 "read_config_grammar.y"
+#line 504 "read_config_grammar.y"
     {
 	   current_encoder_entry = NULL;
 }
     break;
 
   case 73:
-#line 512 "read_config_grammar.y"
+#line 509 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 	   cherokee_matching_list_t *matching;
@@ -1723,7 +1720,7 @@ yyreduce:
     break;
 
   case 74:
-#line 533 "read_config_grammar.y"
+#line 530 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 	   cherokee_matching_list_t *matching;
@@ -1746,7 +1743,7 @@ yyreduce:
     break;
 
   case 75:
-#line 554 "read_config_grammar.y"
+#line 551 "read_config_grammar.y"
     {
 	   FILE *file;
 
@@ -1765,14 +1762,14 @@ yyreduce:
     break;
 
   case 76:
-#line 571 "read_config_grammar.y"
+#line 568 "read_config_grammar.y"
     {
 	   SRV(server)->chroot = yyvsp[0].string;
 }
     break;
 
   case 77:
-#line 576 "read_config_grammar.y"
+#line 573 "read_config_grammar.y"
     {
 #ifdef HAVE_PTHREAD
 	   SRV(server)->ncpus = yyvsp[0].number;
@@ -1781,14 +1778,14 @@ yyreduce:
     break;
 
   case 78:
-#line 583 "read_config_grammar.y"
+#line 580 "read_config_grammar.y"
     {
 	   SRV(server)->ipv6 = yyvsp[0].number;
 }
     break;
 
   case 79:
-#line 588 "read_config_grammar.y"
+#line 585 "read_config_grammar.y"
     {
 	   struct passwd *pwd;
 	   
@@ -1805,14 +1802,14 @@ yyreduce:
     break;
 
   case 80:
-#line 603 "read_config_grammar.y"
+#line 600 "read_config_grammar.y"
     {
 	   SRV(server)->user = yyvsp[0].number;
 }
     break;
 
   case 81:
-#line 608 "read_config_grammar.y"
+#line 605 "read_config_grammar.y"
     {
 	   struct group *grp;
 
@@ -1829,14 +1826,14 @@ yyreduce:
     break;
 
   case 82:
-#line 623 "read_config_grammar.y"
+#line 620 "read_config_grammar.y"
     {
 	   SRV(server)->group = yyvsp[0].number;
 }
     break;
 
   case 83:
-#line 628 "read_config_grammar.y"
+#line 625 "read_config_grammar.y"
     {
 	   yyval.name_ptr.name = yyvsp[-3].string;
 	   yyval.name_ptr.ptr = current_handler_table_entry;
@@ -1844,7 +1841,7 @@ yyreduce:
     break;
 
   case 84:
-#line 634 "read_config_grammar.y"
+#line 631 "read_config_grammar.y"
     {
 	   yyval.name_ptr.name = yyvsp[0].string;
 	   yyval.name_ptr.ptr = current_handler_table_entry;
@@ -1852,51 +1849,51 @@ yyreduce:
     break;
 
   case 85:
-#line 641 "read_config_grammar.y"
+#line 638 "read_config_grammar.y"
     {
 	   cherokee_handler_table_entry_set (current_handler_table_entry, "url", yyvsp[0].string);
 }
     break;
 
   case 86:
-#line 646 "read_config_grammar.y"
+#line 643 "read_config_grammar.y"
     {
 	   cherokee_handler_table_entry_set (current_handler_table_entry, "filedir", yyvsp[0].string);
 }
     break;
 
   case 87:
-#line 651 "read_config_grammar.y"
+#line 648 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "bgcolor", yyvsp[0].string); }
     break;
 
   case 88:
-#line 654 "read_config_grammar.y"
+#line 651 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "text", yyvsp[0].string); }
     break;
 
   case 89:
-#line 657 "read_config_grammar.y"
+#line 654 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "link", yyvsp[0].string); }
     break;
 
   case 90:
-#line 660 "read_config_grammar.y"
+#line 657 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "vlink", yyvsp[0].string); }
     break;
 
   case 91:
-#line 663 "read_config_grammar.y"
+#line 660 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "alink", yyvsp[0].string); }
     break;
 
   case 92:
-#line 666 "read_config_grammar.y"
+#line 663 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "headerfile", yyvsp[0].string); }
     break;
 
   case 93:
-#line 670 "read_config_grammar.y"
+#line 667 "read_config_grammar.y"
     {
 	   linked_list_t *i;
 
@@ -1926,14 +1923,14 @@ yyreduce:
     break;
 
   case 95:
-#line 700 "read_config_grammar.y"
+#line 697 "read_config_grammar.y"
     {
 	   yyval.string = yyvsp[0].string;
 }
     break;
 
   case 96:
-#line 705 "read_config_grammar.y"
+#line 702 "read_config_grammar.y"
     {
 	   linked_list_t *i = yyvsp[-1].list;
 	   CHEROKEE_NEW(vsrv, virtual_server);
@@ -1955,7 +1952,7 @@ yyreduce:
     break;
 
   case 97:
-#line 722 "read_config_grammar.y"
+#line 719 "read_config_grammar.y"
     {
 
 	   current_virtual_server = NULL;
@@ -1963,7 +1960,7 @@ yyreduce:
     break;
 
   case 98:
-#line 729 "read_config_grammar.y"
+#line 726 "read_config_grammar.y"
     {
 	   int name_len;
 
@@ -1980,7 +1977,7 @@ yyreduce:
     break;
 
   case 99:
-#line 743 "read_config_grammar.y"
+#line 740 "read_config_grammar.y"
     {
 	   /* Basic checks
 	    */
@@ -2045,14 +2042,14 @@ out:
     break;
 
   case 100:
-#line 807 "read_config_grammar.y"
+#line 804 "read_config_grammar.y"
     {	   
 	   directory_content_tmp.handler_name = yyvsp[0].name_ptr.name;
 }
     break;
 
   case 101:
-#line 813 "read_config_grammar.y"
+#line 810 "read_config_grammar.y"
     {
 	   int len;
 	   char *new_fdir;
@@ -2065,13 +2062,13 @@ out:
     break;
 
   case 102:
-#line 824 "read_config_grammar.y"
+#line 821 "read_config_grammar.y"
     {
 }
     break;
 
   case 103:
-#line 829 "read_config_grammar.y"
+#line 826 "read_config_grammar.y"
     {
 	   linked_list_t *i, *prev;
 	   CHEROKEE_NEW(n, access);
@@ -2094,7 +2091,7 @@ out:
     break;
 
   case 104:
-#line 851 "read_config_grammar.y"
+#line 848 "read_config_grammar.y"
     {
 	   cherokee_buffer_t *realm;
 	   realm = directory_content_tmp.entry->auth_realm;
@@ -2105,7 +2102,7 @@ out:
     break;
 
   case 105:
-#line 860 "read_config_grammar.y"
+#line 857 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   cherokee_module_info_t *info;
@@ -2127,12 +2124,12 @@ out:
     break;
 
   case 110:
-#line 889 "read_config_grammar.y"
+#line 886 "read_config_grammar.y"
     { cherokee_handler_table_entry_set (current_handler_table_entry, "file", yyvsp[0].string); }
     break;
 
   case 111:
-#line 894 "read_config_grammar.y"
+#line 891 "read_config_grammar.y"
     {
 	   ret_t ret;
 	   int   len;
@@ -2164,7 +2161,7 @@ out:
     break;
 
   case 112:
-#line 925 "read_config_grammar.y"
+#line 922 "read_config_grammar.y"
     {
 	   linked_list_t *i = yyvsp[0].list;
 
@@ -2178,7 +2175,7 @@ out:
     break;
 
   case 113:
-#line 937 "read_config_grammar.y"
+#line 934 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
 	   
@@ -2192,7 +2189,7 @@ out:
     break;
 
   case 114:
-#line 949 "read_config_grammar.y"
+#line 946 "read_config_grammar.y"
     {
 	   cherokee_virtual_server_t *vsrv = auto_virtual_server;
 	   
@@ -2209,7 +2206,7 @@ out:
     }
 
 /* Line 999 of yacc.c.  */
-#line 2213 "read_config_grammar.c"
+#line 2210 "read_config_grammar.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2403,7 +2400,7 @@ yyreturn:
 }
 
 
-#line 960 "read_config_grammar.y"
+#line 957 "read_config_grammar.y"
 
 
 
