@@ -125,7 +125,7 @@ typedef struct {
 	char  *chroot;
 	int    chrooted;
 
-	char  *mimetypes_file;
+	char  *mime_file;
 	char  *icons_file;
 
 	char                           *userdir;              /* Eg: public_html */
