@@ -40,6 +40,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
+#include "buffer.h"
 #include "socket.h"
 #include "virtual_server.h"
 
@@ -237,7 +238,7 @@ cherokee_socket_free (cherokee_socket_t *socket)
 ret_t       
 cherokee_socket_close (cherokee_socket_t *socket)
 {
-	int ret;
+	int re;
 
 	if (socket->socket <= 0) {
 		return ret_error;
@@ -250,11 +251,11 @@ cherokee_socket_close (cherokee_socket_t *socket)
 	}
 #endif
 
-	ret = close (socket->socket);
+	re = close (socket->socket);
 	socket->socket = -1;
 	socket->status = socket_closed;
 
-	return (ret == 0) ? ret_ok : ret_error;
+	return (re == 0) ? ret_ok : ret_error;
 }
 
 
@@ -335,7 +336,7 @@ cherokee_socket_accept (cherokee_socket_t *socket, int server_socket)
 
 
 ret_t       
-cherokee_socket_set_status (cherokee_socket_t  *socket, cherokee_socket_status_t status)
+cherokee_socket_set_status (cherokee_socket_t *socket, cherokee_socket_status_t status)
 {
 	socket->status = status;
 
@@ -348,51 +349,83 @@ cherokee_socket_set_status (cherokee_socket_t  *socket, cherokee_socket_status_t
 
 
 static ret_t 
-cherokee_write (cherokee_socket_t *socket, const char *buf, int buf_len)
+cherokee_write (cherokee_socket_t *socket, const char *buf, int buf_len, int *writed)
 {
 	ssize_t rc;
 
 #if HAVE_TLS
+
 #else
 	rc = write (SOCKET_FD(socket), buf, buf_len);
 #endif
-
+	
 	if (rc < 0) {
+		switch (errno) {
+		case EAGAIN:     return ret_eagain;
+		case EPIPE:      return ret_eof;
+		case ECONNRESET: return ret_eof;
+		}
+	
+		PRINT_ERROR ("Unknown error: write(%d, ..) -> errno=%d '%s'\n", 
+			     SOCKET_FD(socket), errno, strerror(errno));
 		return ret_error;
 	}
 
+	/* Return info
+	 */
+	*writed = rc;
 	return ret_ok;
 }
 
 
 static ret_t
-cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, int *readed)
+cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, ssize_t *readed)
 {
-	ssize_t rc;
-
 #ifdef HAVE_TLS
+
 #else	
-	rc = read (SOCKET_FD(socket), buf, buf_size);
+	*readed = read (SOCKET_FD(socket), buf, buf_size);
 #endif
 
-	if (rc < 0) {
+	if (*readed < 0) {
+		switch (errno) {
+		case EAGAIN:     return ret_eagain;
+		case EPIPE:      return ret_eof;
+		case ECONNRESET: return ret_eof;
+		}
+
+		PRINT_ERROR ("Unknown error: read(%d, ..) -> errno=%d '%s'\n", 
+			     SOCKET_FD(socket), errno, strerror(errno));
 		return ret_error;
+
+	} else if (*readed == 0) {
+		return ret_eof;
 	}
 	
-	*readed = (int)rc;
 	return ret_ok;
 }
 
 
 ret_t       
-cherokee_socket_write (cherokee_socket_t *socket, cherokee_buffer_t *buf)
+cherokee_socket_write (cherokee_socket_t *socket, cherokee_buffer_t *buf, size_t *writed)
 {
-	return cherokee_write (socket, buf->buf, buf->len);
+	return cherokee_write (socket, buf->buf, buf->len, writed);
 }
 
 
 ret_t      
-cherokee_socket_read (cherokee_socket_t *socket, cherokee_buffer_t *buf)
+cherokee_socket_read (cherokee_socket_t *socket, cherokee_buffer_t *buf, size_t count, ssize_t *readed)
 {
-	return cherokee_read (socket, buf->buf, buf->size, &buf->len);
+	ret_t    ret;
+	char    *starting;
+	
+	cherokee_buffer_ensure_size (buf, buf->len + count);
+	starting = buf->buf + buf->len;
+
+	ret = cherokee_read (socket, starting, count, readed);
+	if (ret == ret_ok) {
+		buf->len += *readed;
+	}
+
+	return ret;
 }
